@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -79,7 +79,7 @@ __all__ = ("CloudWatchClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -103,7 +103,7 @@ class Exceptions:
 
 class CloudWatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html)
     """
 
@@ -119,15 +119,15 @@ class CloudWatchClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#can_paginate)
         """
 
-    def delete_alarms(self, *, AlarmNames: List[str]) -> None:
+    def delete_alarms(self, *, AlarmNames: Sequence[str]) -> None:
         """
         Deletes the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_alarms)
         """
 
@@ -137,28 +137,28 @@ class CloudWatchClient(BaseClient):
         Namespace: str,
         MetricName: str,
         Stat: str,
-        Dimensions: List["DimensionTypeDef"] = None
+        Dimensions: Sequence["DimensionTypeDef"] = None
     ) -> Dict[str, Any]:
         """
         Deletes the specified anomaly detection model from your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_anomaly_detector)
         """
 
-    def delete_dashboards(self, *, DashboardNames: List[str]) -> Dict[str, Any]:
+    def delete_dashboards(self, *, DashboardNames: Sequence[str]) -> Dict[str, Any]:
         """
         Deletes all dashboards that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_dashboards)
         """
 
-    def delete_insight_rules(self, *, RuleNames: List[str]) -> DeleteInsightRulesOutputTypeDef:
+    def delete_insight_rules(self, *, RuleNames: Sequence[str]) -> DeleteInsightRulesOutputTypeDef:
         """
         Permanently deletes the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_insight_rules)
         """
 
@@ -166,7 +166,7 @@ class CloudWatchClient(BaseClient):
         """
         Permanently deletes the metric stream that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.delete_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.delete_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_metric_stream)
         """
 
@@ -174,7 +174,7 @@ class CloudWatchClient(BaseClient):
         self,
         *,
         AlarmName: str = None,
-        AlarmTypes: List[AlarmTypeType] = None,
+        AlarmTypes: Sequence[AlarmTypeType] = None,
         HistoryItemType: HistoryItemTypeType = None,
         StartDate: Union[datetime, str] = None,
         EndDate: Union[datetime, str] = None,
@@ -185,16 +185,16 @@ class CloudWatchClient(BaseClient):
         """
         Retrieves the history for the specified alarm.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarm_history)
         """
 
     def describe_alarms(
         self,
         *,
-        AlarmNames: List[str] = None,
+        AlarmNames: Sequence[str] = None,
         AlarmNamePrefix: str = None,
-        AlarmTypes: List[AlarmTypeType] = None,
+        AlarmTypes: Sequence[AlarmTypeType] = None,
         ChildrenOfAlarmName: str = None,
         ParentsOfAlarmName: str = None,
         StateValue: StateValueType = None,
@@ -205,7 +205,7 @@ class CloudWatchClient(BaseClient):
         """
         Retrieves the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarms)
         """
 
@@ -216,14 +216,14 @@ class CloudWatchClient(BaseClient):
         Namespace: str,
         Statistic: StatisticType = None,
         ExtendedStatistic: str = None,
-        Dimensions: List["DimensionTypeDef"] = None,
+        Dimensions: Sequence["DimensionTypeDef"] = None,
         Period: int = None,
         Unit: StandardUnitType = None
     ) -> DescribeAlarmsForMetricOutputTypeDef:
         """
         Retrieves the alarms for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarms_for_metric)
         """
 
@@ -234,12 +234,12 @@ class CloudWatchClient(BaseClient):
         MaxResults: int = None,
         Namespace: str = None,
         MetricName: str = None,
-        Dimensions: List["DimensionTypeDef"] = None
+        Dimensions: Sequence["DimensionTypeDef"] = None
     ) -> DescribeAnomalyDetectorsOutputTypeDef:
         """
         Lists the anomaly detection models that you have created in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_anomaly_detectors)
         """
 
@@ -249,53 +249,55 @@ class CloudWatchClient(BaseClient):
         """
         Returns a list of all the Contributor Insights rules in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_insight_rules)
         """
 
-    def disable_alarm_actions(self, *, AlarmNames: List[str]) -> None:
+    def disable_alarm_actions(self, *, AlarmNames: Sequence[str]) -> None:
         """
         Disables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#disable_alarm_actions)
         """
 
-    def disable_insight_rules(self, *, RuleNames: List[str]) -> DisableInsightRulesOutputTypeDef:
+    def disable_insight_rules(
+        self, *, RuleNames: Sequence[str]
+    ) -> DisableInsightRulesOutputTypeDef:
         """
         Disables the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#disable_insight_rules)
         """
 
-    def enable_alarm_actions(self, *, AlarmNames: List[str]) -> None:
+    def enable_alarm_actions(self, *, AlarmNames: Sequence[str]) -> None:
         """
         Enables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#enable_alarm_actions)
         """
 
-    def enable_insight_rules(self, *, RuleNames: List[str]) -> EnableInsightRulesOutputTypeDef:
+    def enable_insight_rules(self, *, RuleNames: Sequence[str]) -> EnableInsightRulesOutputTypeDef:
         """
         Enables the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#enable_insight_rules)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#generate_presigned_url)
         """
 
@@ -303,7 +305,7 @@ class CloudWatchClient(BaseClient):
         """
         Displays the details of the dashboard that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_dashboard)
         """
 
@@ -315,21 +317,21 @@ class CloudWatchClient(BaseClient):
         EndTime: Union[datetime, str],
         Period: int,
         MaxContributorCount: int = None,
-        Metrics: List[str] = None,
+        Metrics: Sequence[str] = None,
         OrderBy: str = None
     ) -> GetInsightRuleReportOutputTypeDef:
         """
         This operation returns the time series data collected by a Contributor Insights
         rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_insight_rule_report)
         """
 
     def get_metric_data(
         self,
         *,
-        MetricDataQueries: List["MetricDataQueryTypeDef"],
+        MetricDataQueries: Sequence["MetricDataQueryTypeDef"],
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         NextToken: str = None,
@@ -341,7 +343,7 @@ class CloudWatchClient(BaseClient):
         You can use the `GetMetricData` API to retrieve as many as 500 different metrics
         in a single request, with a total of as many as 100,800 data points.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_data)
         """
 
@@ -353,15 +355,15 @@ class CloudWatchClient(BaseClient):
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         Period: int,
-        Dimensions: List["DimensionTypeDef"] = None,
-        Statistics: List[StatisticType] = None,
-        ExtendedStatistics: List[str] = None,
+        Dimensions: Sequence["DimensionTypeDef"] = None,
+        Statistics: Sequence[StatisticType] = None,
+        ExtendedStatistics: Sequence[str] = None,
         Unit: StandardUnitType = None
     ) -> GetMetricStatisticsOutputTypeDef:
         """
         Gets statistics for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_statistics)
         """
 
@@ -369,7 +371,7 @@ class CloudWatchClient(BaseClient):
         """
         Returns information about the metric stream that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_stream)
         """
 
@@ -380,7 +382,7 @@ class CloudWatchClient(BaseClient):
         You can use the `GetMetricWidgetImage` API to retrieve a snapshot graph of one
         or more Amazon CloudWatch metrics as a bitmap image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_widget_image)
         """
 
@@ -390,7 +392,7 @@ class CloudWatchClient(BaseClient):
         """
         Returns a list of the dashboards for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_dashboards)
         """
 
@@ -400,7 +402,7 @@ class CloudWatchClient(BaseClient):
         """
         Returns a list of metric streams in this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.list_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.list_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_metric_streams)
         """
 
@@ -409,14 +411,14 @@ class CloudWatchClient(BaseClient):
         *,
         Namespace: str = None,
         MetricName: str = None,
-        Dimensions: List["DimensionFilterTypeDef"] = None,
+        Dimensions: Sequence["DimensionFilterTypeDef"] = None,
         NextToken: str = None,
         RecentlyActive: Literal["PT3H"] = None
     ) -> ListMetricsOutputTypeDef:
         """
         List the specified metrics.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_metrics)
         """
 
@@ -424,7 +426,7 @@ class CloudWatchClient(BaseClient):
         """
         Displays the tags associated with a CloudWatch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_tags_for_resource)
         """
 
@@ -434,13 +436,13 @@ class CloudWatchClient(BaseClient):
         Namespace: str,
         MetricName: str,
         Stat: str,
-        Dimensions: List["DimensionTypeDef"] = None,
+        Dimensions: Sequence["DimensionTypeDef"] = None,
         Configuration: "AnomalyDetectorConfigurationTypeDef" = None
     ) -> Dict[str, Any]:
         """
         Creates an anomaly detection model for a CloudWatch metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_anomaly_detector)
         """
 
@@ -450,16 +452,16 @@ class CloudWatchClient(BaseClient):
         AlarmName: str,
         AlarmRule: str,
         ActionsEnabled: bool = None,
-        AlarmActions: List[str] = None,
+        AlarmActions: Sequence[str] = None,
         AlarmDescription: str = None,
-        InsufficientDataActions: List[str] = None,
-        OKActions: List[str] = None,
-        Tags: List["TagTypeDef"] = None
+        InsufficientDataActions: Sequence[str] = None,
+        OKActions: Sequence[str] = None,
+        Tags: Sequence["TagTypeDef"] = None
     ) -> None:
         """
         Creates or updates a *composite alarm*.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_composite_alarm)
         """
 
@@ -468,7 +470,7 @@ class CloudWatchClient(BaseClient):
         Creates a dashboard if it does not already exist, or updates an existing
         dashboard.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_dashboard)
         """
 
@@ -478,12 +480,12 @@ class CloudWatchClient(BaseClient):
         RuleName: str,
         RuleDefinition: str,
         RuleState: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> Dict[str, Any]:
         """
         Creates a Contributor Insights rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_insight_rule)
         """
 
@@ -495,37 +497,39 @@ class CloudWatchClient(BaseClient):
         ComparisonOperator: ComparisonOperatorType,
         AlarmDescription: str = None,
         ActionsEnabled: bool = None,
-        OKActions: List[str] = None,
-        AlarmActions: List[str] = None,
-        InsufficientDataActions: List[str] = None,
+        OKActions: Sequence[str] = None,
+        AlarmActions: Sequence[str] = None,
+        InsufficientDataActions: Sequence[str] = None,
         MetricName: str = None,
         Namespace: str = None,
         Statistic: StatisticType = None,
         ExtendedStatistic: str = None,
-        Dimensions: List["DimensionTypeDef"] = None,
+        Dimensions: Sequence["DimensionTypeDef"] = None,
         Period: int = None,
         Unit: StandardUnitType = None,
         DatapointsToAlarm: int = None,
         Threshold: float = None,
         TreatMissingData: str = None,
         EvaluateLowSampleCountPercentile: str = None,
-        Metrics: List["MetricDataQueryTypeDef"] = None,
-        Tags: List["TagTypeDef"] = None,
+        Metrics: Sequence["MetricDataQueryTypeDef"] = None,
+        Tags: Sequence["TagTypeDef"] = None,
         ThresholdMetricId: str = None
     ) -> None:
         """
         Creates or updates an alarm and associates it with the specified metric, metric
         math expression, or anomaly detection model.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_alarm)
         """
 
-    def put_metric_data(self, *, Namespace: str, MetricData: List["MetricDatumTypeDef"]) -> None:
+    def put_metric_data(
+        self, *, Namespace: str, MetricData: Sequence["MetricDatumTypeDef"]
+    ) -> None:
         """
         Publishes metric data points to Amazon CloudWatch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_data)
         """
 
@@ -536,14 +540,14 @@ class CloudWatchClient(BaseClient):
         FirehoseArn: str,
         RoleArn: str,
         OutputFormat: MetricStreamOutputFormatType,
-        IncludeFilters: List["MetricStreamFilterTypeDef"] = None,
-        ExcludeFilters: List["MetricStreamFilterTypeDef"] = None,
-        Tags: List["TagTypeDef"] = None
+        IncludeFilters: Sequence["MetricStreamFilterTypeDef"] = None,
+        ExcludeFilters: Sequence["MetricStreamFilterTypeDef"] = None,
+        Tags: Sequence["TagTypeDef"] = None
     ) -> PutMetricStreamOutputTypeDef:
         """
         Creates or updates a metric stream.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_stream)
         """
 
@@ -558,39 +562,39 @@ class CloudWatchClient(BaseClient):
         """
         Temporarily sets the state of an alarm for testing purposes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#set_alarm_state)
         """
 
-    def start_metric_streams(self, *, Names: List[str]) -> Dict[str, Any]:
+    def start_metric_streams(self, *, Names: Sequence[str]) -> Dict[str, Any]:
         """
         Starts the streaming of metrics for one or more of your metric streams.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.start_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.start_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#start_metric_streams)
         """
 
-    def stop_metric_streams(self, *, Names: List[str]) -> Dict[str, Any]:
+    def stop_metric_streams(self, *, Names: Sequence[str]) -> Dict[str, Any]:
         """
         Stops the streaming of metrics for one or more of your metric streams.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.stop_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.stop_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#stop_metric_streams)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Assigns one or more tags (key-value pairs) to the specified CloudWatch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes one or more tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#untag_resource)
         """
 
@@ -599,42 +603,42 @@ class CloudWatchClient(BaseClient):
         self, operation_name: Literal["describe_alarm_history"]
     ) -> DescribeAlarmHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_alarms"]) -> DescribeAlarmsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_metric_data"]) -> GetMetricDataPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_dashboards"]) -> ListDashboardsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_metrics"]) -> ListMetricsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["alarm_exists"]) -> AlarmExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
         """
 
@@ -643,6 +647,6 @@ class CloudWatchClient(BaseClient):
         self, waiter_name: Literal["composite_alarm_exists"]
     ) -> CompositeAlarmExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
         """
