@@ -19,7 +19,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Iterator, List, Union
+from typing import Any, Iterator, List, Sequence, Union
 
 from boto3.resources.base import ResourceMeta
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
@@ -62,7 +62,7 @@ __all__ = (
 
 class ServiceResourceAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcealarmscollection)
     """
 
@@ -74,9 +74,9 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
     def filter(  # type: ignore
         self,
         *,
-        AlarmNames: List[str] = None,
+        AlarmNames: Sequence[str] = None,
         AlarmNamePrefix: str = None,
-        AlarmTypes: List[AlarmTypeType] = None,
+        AlarmTypes: Sequence[AlarmTypeType] = None,
         ChildrenOfAlarmName: str = None,
         ParentsOfAlarmName: str = None,
         StateValue: StateValueType = None,
@@ -126,7 +126,7 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
 
 class ServiceResourceMetricsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcemetricscollection)
     """
 
@@ -140,7 +140,7 @@ class ServiceResourceMetricsCollection(ResourceCollection):
         *,
         Namespace: str = None,
         MetricName: str = None,
-        Dimensions: List["DimensionFilterTypeDef"] = None,
+        Dimensions: Sequence["DimensionFilterTypeDef"] = None,
         NextToken: str = None,
         RecentlyActive: Literal["PT3H"] = None
     ) -> "ServiceResourceMetricsCollection":
@@ -171,7 +171,7 @@ class ServiceResourceMetricsCollection(ResourceCollection):
 
 class MetricAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricalarmscollection)
     """
 
@@ -185,7 +185,7 @@ class MetricAlarmsCollection(ResourceCollection):
         *,
         Statistic: StatisticType = None,
         ExtendedStatistic: str = None,
-        Dimensions: List["DimensionTypeDef"] = None,
+        Dimensions: Sequence["DimensionTypeDef"] = None,
         Period: int = None,
         Unit: StandardUnitType = None
     ) -> "MetricAlarmsCollection":
@@ -231,7 +231,7 @@ class MetricAlarmsCollection(ResourceCollection):
 
 class Alarm(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarm)
     """
 
@@ -269,14 +269,14 @@ class Alarm(Boto3ServiceResource):
         """
         Deletes the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdelete-method)
         """
 
     def describe_history(
         self,
         *,
-        AlarmTypes: List[AlarmTypeType] = None,
+        AlarmTypes: Sequence[AlarmTypeType] = None,
         HistoryItemType: HistoryItemTypeType = None,
         StartDate: Union[datetime, str] = None,
         EndDate: Union[datetime, str] = None,
@@ -287,7 +287,7 @@ class Alarm(Boto3ServiceResource):
         """
         Retrieves the history for the specified alarm.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdescribe_history-method)
         """
 
@@ -295,7 +295,7 @@ class Alarm(Boto3ServiceResource):
         """
         Disables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdisable_actions-method)
         """
 
@@ -303,15 +303,15 @@ class Alarm(Boto3ServiceResource):
         """
         Enables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmenable_actions-method)
         """
 
-    def get_available_subresources(self) -> List[str]:
+    def get_available_subresources(self) -> Sequence[str]:
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmget_available_subresources-method)
         """
 
@@ -320,7 +320,7 @@ class Alarm(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.describe_alarms` to update the attributes of
         the Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmload-method)
         """
 
@@ -329,7 +329,7 @@ class Alarm(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.describe_alarms` to update the attributes of
         the Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmreload-method)
         """
 
@@ -339,7 +339,7 @@ class Alarm(Boto3ServiceResource):
         """
         Temporarily sets the state of an alarm for testing purposes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmset_state-method)
         """
 
@@ -349,7 +349,7 @@ _Alarm = Alarm
 
 class Metric(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metric)
     """
 
@@ -359,11 +359,11 @@ class Metric(Boto3ServiceResource):
     name: str
     alarms: MetricAlarmsCollection
 
-    def get_available_subresources(self) -> List[str]:
+    def get_available_subresources(self) -> Sequence[str]:
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_available_subresources-method)
         """
 
@@ -373,15 +373,15 @@ class Metric(Boto3ServiceResource):
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         Period: int,
-        Dimensions: List["DimensionTypeDef"] = None,
-        Statistics: List[StatisticType] = None,
-        ExtendedStatistics: List[str] = None,
+        Dimensions: Sequence["DimensionTypeDef"] = None,
+        Statistics: Sequence[StatisticType] = None,
+        ExtendedStatistics: Sequence[str] = None,
         Unit: StandardUnitType = None
     ) -> GetMetricStatisticsOutputTypeDef:
         """
         Gets statistics for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_statistics-method)
         """
 
@@ -390,7 +390,7 @@ class Metric(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.list_metrics` to update the attributes of the
         Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Metric.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Metric.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricload-method)
         """
 
@@ -402,27 +402,27 @@ class Metric(Boto3ServiceResource):
         ComparisonOperator: ComparisonOperatorType,
         AlarmDescription: str = None,
         ActionsEnabled: bool = None,
-        OKActions: List[str] = None,
-        AlarmActions: List[str] = None,
-        InsufficientDataActions: List[str] = None,
+        OKActions: Sequence[str] = None,
+        AlarmActions: Sequence[str] = None,
+        InsufficientDataActions: Sequence[str] = None,
         Statistic: StatisticType = None,
         ExtendedStatistic: str = None,
-        Dimensions: List["DimensionTypeDef"] = None,
+        Dimensions: Sequence["DimensionTypeDef"] = None,
         Period: int = None,
         Unit: StandardUnitType = None,
         DatapointsToAlarm: int = None,
         Threshold: float = None,
         TreatMissingData: str = None,
         EvaluateLowSampleCountPercentile: str = None,
-        Metrics: List["MetricDataQueryTypeDef"] = None,
-        Tags: List["TagTypeDef"] = None,
+        Metrics: Sequence["MetricDataQueryTypeDef"] = None,
+        Tags: Sequence["TagTypeDef"] = None,
         ThresholdMetricId: str = None
     ) -> _Alarm:
         """
         Creates or updates an alarm and associates it with the specified metric, metric
         math expression, or anomaly detection model.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_alarm-method)
         """
 
@@ -430,7 +430,7 @@ class Metric(Boto3ServiceResource):
         """
         Publishes metric data points to Amazon CloudWatch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_data-method)
         """
 
@@ -439,7 +439,7 @@ class Metric(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.list_metrics` to update the attributes of the
         Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricreload-method)
         """
 
@@ -453,7 +453,7 @@ class CloudWatchResourceMeta(ResourceMeta):
 
 class CloudWatchServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html)
     """
 
@@ -465,7 +465,7 @@ class CloudWatchServiceResource(Boto3ServiceResource):
         """
         Creates a Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcealarm-method)
         """
 
@@ -473,14 +473,14 @@ class CloudWatchServiceResource(Boto3ServiceResource):
         """
         Creates a Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcemetric-method)
         """
 
-    def get_available_subresources(self) -> List[str]:
+    def get_available_subresources(self) -> Sequence[str]:
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourceget_available_subresources-method)
         """
