@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import (
     AlarmTypeType,
@@ -226,7 +226,7 @@ DatapointTypeDef = TypedDict(
 DeleteAlarmsInputRequestTypeDef = TypedDict(
     "DeleteAlarmsInputRequestTypeDef",
     {
-        "AlarmNames": List[str],
+        "AlarmNames": Sequence[str],
     },
 )
 
@@ -241,7 +241,7 @@ _RequiredDeleteAnomalyDetectorInputRequestTypeDef = TypedDict(
 _OptionalDeleteAnomalyDetectorInputRequestTypeDef = TypedDict(
     "_OptionalDeleteAnomalyDetectorInputRequestTypeDef",
     {
-        "Dimensions": List["DimensionTypeDef"],
+        "Dimensions": Sequence["DimensionTypeDef"],
     },
     total=False,
 )
@@ -257,14 +257,14 @@ class DeleteAnomalyDetectorInputRequestTypeDef(
 DeleteDashboardsInputRequestTypeDef = TypedDict(
     "DeleteDashboardsInputRequestTypeDef",
     {
-        "DashboardNames": List[str],
+        "DashboardNames": Sequence[str],
     },
 )
 
 DeleteInsightRulesInputRequestTypeDef = TypedDict(
     "DeleteInsightRulesInputRequestTypeDef",
     {
-        "RuleNames": List[str],
+        "RuleNames": Sequence[str],
     },
 )
 
@@ -286,7 +286,7 @@ DeleteMetricStreamInputRequestTypeDef = TypedDict(
 DescribeAlarmHistoryInputAlarmTypeDef = TypedDict(
     "DescribeAlarmHistoryInputAlarmTypeDef",
     {
-        "AlarmTypes": List[AlarmTypeType],
+        "AlarmTypes": Sequence[AlarmTypeType],
         "HistoryItemType": HistoryItemTypeType,
         "StartDate": Union[datetime, str],
         "EndDate": Union[datetime, str],
@@ -301,7 +301,7 @@ DescribeAlarmHistoryInputRequestTypeDef = TypedDict(
     "DescribeAlarmHistoryInputRequestTypeDef",
     {
         "AlarmName": str,
-        "AlarmTypes": List[AlarmTypeType],
+        "AlarmTypes": Sequence[AlarmTypeType],
         "HistoryItemType": HistoryItemTypeType,
         "StartDate": Union[datetime, str],
         "EndDate": Union[datetime, str],
@@ -333,7 +333,7 @@ _OptionalDescribeAlarmsForMetricInputRequestTypeDef = TypedDict(
     {
         "Statistic": StatisticType,
         "ExtendedStatistic": str,
-        "Dimensions": List["DimensionTypeDef"],
+        "Dimensions": Sequence["DimensionTypeDef"],
         "Period": int,
         "Unit": StandardUnitType,
     },
@@ -359,9 +359,9 @@ DescribeAlarmsForMetricOutputTypeDef = TypedDict(
 DescribeAlarmsInputRequestTypeDef = TypedDict(
     "DescribeAlarmsInputRequestTypeDef",
     {
-        "AlarmNames": List[str],
+        "AlarmNames": Sequence[str],
         "AlarmNamePrefix": str,
-        "AlarmTypes": List[AlarmTypeType],
+        "AlarmTypes": Sequence[AlarmTypeType],
         "ChildrenOfAlarmName": str,
         "ParentsOfAlarmName": str,
         "StateValue": StateValueType,
@@ -389,7 +389,7 @@ DescribeAnomalyDetectorsInputRequestTypeDef = TypedDict(
         "MaxResults": int,
         "Namespace": str,
         "MetricName": str,
-        "Dimensions": List["DimensionTypeDef"],
+        "Dimensions": Sequence["DimensionTypeDef"],
     },
     total=False,
 )
@@ -451,14 +451,14 @@ DimensionTypeDef = TypedDict(
 DisableAlarmActionsInputRequestTypeDef = TypedDict(
     "DisableAlarmActionsInputRequestTypeDef",
     {
-        "AlarmNames": List[str],
+        "AlarmNames": Sequence[str],
     },
 )
 
 DisableInsightRulesInputRequestTypeDef = TypedDict(
     "DisableInsightRulesInputRequestTypeDef",
     {
-        "RuleNames": List[str],
+        "RuleNames": Sequence[str],
     },
 )
 
@@ -473,14 +473,14 @@ DisableInsightRulesOutputTypeDef = TypedDict(
 EnableAlarmActionsInputRequestTypeDef = TypedDict(
     "EnableAlarmActionsInputRequestTypeDef",
     {
-        "AlarmNames": List[str],
+        "AlarmNames": Sequence[str],
     },
 )
 
 EnableInsightRulesInputRequestTypeDef = TypedDict(
     "EnableInsightRulesInputRequestTypeDef",
     {
-        "RuleNames": List[str],
+        "RuleNames": Sequence[str],
     },
 )
 
@@ -522,7 +522,7 @@ _OptionalGetInsightRuleReportInputRequestTypeDef = TypedDict(
     "_OptionalGetInsightRuleReportInputRequestTypeDef",
     {
         "MaxContributorCount": int,
-        "Metrics": List[str],
+        "Metrics": Sequence[str],
         "OrderBy": str,
     },
     total=False,
@@ -552,7 +552,7 @@ GetInsightRuleReportOutputTypeDef = TypedDict(
 _RequiredGetMetricDataInputRequestTypeDef = TypedDict(
     "_RequiredGetMetricDataInputRequestTypeDef",
     {
-        "MetricDataQueries": List["MetricDataQueryTypeDef"],
+        "MetricDataQueries": Sequence["MetricDataQueryTypeDef"],
         "StartTime": Union[datetime, str],
         "EndTime": Union[datetime, str],
     },
@@ -596,9 +596,9 @@ _RequiredGetMetricStatisticsInputMetricTypeDef = TypedDict(
 _OptionalGetMetricStatisticsInputMetricTypeDef = TypedDict(
     "_OptionalGetMetricStatisticsInputMetricTypeDef",
     {
-        "Dimensions": List["DimensionTypeDef"],
-        "Statistics": List[StatisticType],
-        "ExtendedStatistics": List[str],
+        "Dimensions": Sequence["DimensionTypeDef"],
+        "Statistics": Sequence[StatisticType],
+        "ExtendedStatistics": Sequence[str],
         "Unit": StandardUnitType,
     },
     total=False,
@@ -624,9 +624,9 @@ _RequiredGetMetricStatisticsInputRequestTypeDef = TypedDict(
 _OptionalGetMetricStatisticsInputRequestTypeDef = TypedDict(
     "_OptionalGetMetricStatisticsInputRequestTypeDef",
     {
-        "Dimensions": List["DimensionTypeDef"],
-        "Statistics": List[StatisticType],
-        "ExtendedStatistics": List[str],
+        "Dimensions": Sequence["DimensionTypeDef"],
+        "Statistics": Sequence[StatisticType],
+        "ExtendedStatistics": Sequence[str],
         "Unit": StandardUnitType,
     },
     total=False,
@@ -805,7 +805,7 @@ ListMetricsInputRequestTypeDef = TypedDict(
     {
         "Namespace": str,
         "MetricName": str,
-        "Dimensions": List["DimensionFilterTypeDef"],
+        "Dimensions": Sequence["DimensionFilterTypeDef"],
         "NextToken": str,
         "RecentlyActive": Literal["PT3H"],
     },
@@ -925,12 +925,12 @@ _RequiredMetricDatumTypeDef = TypedDict(
 _OptionalMetricDatumTypeDef = TypedDict(
     "_OptionalMetricDatumTypeDef",
     {
-        "Dimensions": List["DimensionTypeDef"],
+        "Dimensions": Sequence["DimensionTypeDef"],
         "Timestamp": Union[datetime, str],
         "Value": float,
         "StatisticValues": "StatisticSetTypeDef",
-        "Values": List[float],
-        "Counts": List[float],
+        "Values": Sequence[float],
+        "Counts": Sequence[float],
         "Unit": StandardUnitType,
         "StorageResolution": int,
     },
@@ -1027,7 +1027,7 @@ _RequiredPutAnomalyDetectorInputRequestTypeDef = TypedDict(
 _OptionalPutAnomalyDetectorInputRequestTypeDef = TypedDict(
     "_OptionalPutAnomalyDetectorInputRequestTypeDef",
     {
-        "Dimensions": List["DimensionTypeDef"],
+        "Dimensions": Sequence["DimensionTypeDef"],
         "Configuration": "AnomalyDetectorConfigurationTypeDef",
     },
     total=False,
@@ -1051,11 +1051,11 @@ _OptionalPutCompositeAlarmInputRequestTypeDef = TypedDict(
     "_OptionalPutCompositeAlarmInputRequestTypeDef",
     {
         "ActionsEnabled": bool,
-        "AlarmActions": List[str],
+        "AlarmActions": Sequence[str],
         "AlarmDescription": str,
-        "InsufficientDataActions": List[str],
-        "OKActions": List[str],
-        "Tags": List["TagTypeDef"],
+        "InsufficientDataActions": Sequence[str],
+        "OKActions": Sequence[str],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1094,7 +1094,7 @@ _OptionalPutInsightRuleInputRequestTypeDef = TypedDict(
     "_OptionalPutInsightRuleInputRequestTypeDef",
     {
         "RuleState": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1119,20 +1119,20 @@ _OptionalPutMetricAlarmInputMetricTypeDef = TypedDict(
     {
         "AlarmDescription": str,
         "ActionsEnabled": bool,
-        "OKActions": List[str],
-        "AlarmActions": List[str],
-        "InsufficientDataActions": List[str],
+        "OKActions": Sequence[str],
+        "AlarmActions": Sequence[str],
+        "InsufficientDataActions": Sequence[str],
         "Statistic": StatisticType,
         "ExtendedStatistic": str,
-        "Dimensions": List["DimensionTypeDef"],
+        "Dimensions": Sequence["DimensionTypeDef"],
         "Period": int,
         "Unit": StandardUnitType,
         "DatapointsToAlarm": int,
         "Threshold": float,
         "TreatMissingData": str,
         "EvaluateLowSampleCountPercentile": str,
-        "Metrics": List["MetricDataQueryTypeDef"],
-        "Tags": List["TagTypeDef"],
+        "Metrics": Sequence["MetricDataQueryTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "ThresholdMetricId": str,
     },
     total=False,
@@ -1158,22 +1158,22 @@ _OptionalPutMetricAlarmInputRequestTypeDef = TypedDict(
     {
         "AlarmDescription": str,
         "ActionsEnabled": bool,
-        "OKActions": List[str],
-        "AlarmActions": List[str],
-        "InsufficientDataActions": List[str],
+        "OKActions": Sequence[str],
+        "AlarmActions": Sequence[str],
+        "InsufficientDataActions": Sequence[str],
         "MetricName": str,
         "Namespace": str,
         "Statistic": StatisticType,
         "ExtendedStatistic": str,
-        "Dimensions": List["DimensionTypeDef"],
+        "Dimensions": Sequence["DimensionTypeDef"],
         "Period": int,
         "Unit": StandardUnitType,
         "DatapointsToAlarm": int,
         "Threshold": float,
         "TreatMissingData": str,
         "EvaluateLowSampleCountPercentile": str,
-        "Metrics": List["MetricDataQueryTypeDef"],
-        "Tags": List["TagTypeDef"],
+        "Metrics": Sequence["MetricDataQueryTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "ThresholdMetricId": str,
     },
     total=False,
@@ -1190,7 +1190,7 @@ PutMetricDataInputRequestTypeDef = TypedDict(
     "PutMetricDataInputRequestTypeDef",
     {
         "Namespace": str,
-        "MetricData": List["MetricDatumTypeDef"],
+        "MetricData": Sequence["MetricDatumTypeDef"],
     },
 )
 
@@ -1206,9 +1206,9 @@ _RequiredPutMetricStreamInputRequestTypeDef = TypedDict(
 _OptionalPutMetricStreamInputRequestTypeDef = TypedDict(
     "_OptionalPutMetricStreamInputRequestTypeDef",
     {
-        "IncludeFilters": List["MetricStreamFilterTypeDef"],
-        "ExcludeFilters": List["MetricStreamFilterTypeDef"],
-        "Tags": List["TagTypeDef"],
+        "IncludeFilters": Sequence["MetricStreamFilterTypeDef"],
+        "ExcludeFilters": Sequence["MetricStreamFilterTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1310,7 +1310,7 @@ class SetAlarmStateInputRequestTypeDef(
 StartMetricStreamsInputRequestTypeDef = TypedDict(
     "StartMetricStreamsInputRequestTypeDef",
     {
-        "Names": List[str],
+        "Names": Sequence[str],
     },
 )
 
@@ -1327,7 +1327,7 @@ StatisticSetTypeDef = TypedDict(
 StopMetricStreamsInputRequestTypeDef = TypedDict(
     "StopMetricStreamsInputRequestTypeDef",
     {
-        "Names": List[str],
+        "Names": Sequence[str],
     },
 )
 
@@ -1335,7 +1335,7 @@ TagResourceInputRequestTypeDef = TypedDict(
     "TagResourceInputRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1351,7 +1351,7 @@ UntagResourceInputRequestTypeDef = TypedDict(
     "UntagResourceInputRequestTypeDef",
     {
         "ResourceARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
