@@ -20,7 +20,7 @@ Usage::
     composite_alarm_exists_waiter: CompositeAlarmExistsWaiter = client.get_waiter("composite_alarm_exists")
     ```
 """
-from typing import List
+from typing import Sequence
 
 from botocore.waiter import Waiter as Boto3Waiter
 
@@ -32,16 +32,16 @@ __all__ = ("AlarmExistsWaiter", "CompositeAlarmExistsWaiter")
 
 class AlarmExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
     """
 
     def wait(
         self,
         *,
-        AlarmNames: List[str] = None,
+        AlarmNames: Sequence[str] = None,
         AlarmNamePrefix: str = None,
-        AlarmTypes: List[AlarmTypeType] = None,
+        AlarmTypes: Sequence[AlarmTypeType] = None,
         ChildrenOfAlarmName: str = None,
         ParentsOfAlarmName: str = None,
         StateValue: StateValueType = None,
@@ -51,23 +51,23 @@ class AlarmExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
         """
 
 
 class CompositeAlarmExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
     """
 
     def wait(
         self,
         *,
-        AlarmNames: List[str] = None,
+        AlarmNames: Sequence[str] = None,
         AlarmNamePrefix: str = None,
-        AlarmTypes: List[AlarmTypeType] = None,
+        AlarmTypes: Sequence[AlarmTypeType] = None,
         ChildrenOfAlarmName: str = None,
         ParentsOfAlarmName: str = None,
         StateValue: StateValueType = None,
@@ -77,6 +77,6 @@ class CompositeAlarmExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
         """
